"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spellNumberInAz = void 0;

var _integer = _interopRequireDefault(require("./spelling/integer"));

var _float = _interopRequireDefault(require("./spelling/float"));

var _helpers = require("./utils/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * MIT License

Copyright (c) 2018 Orkhan Huseynli

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
 */

/**
 * Generalized spell number function
 * @param {input} number - any integer or floating point number
 * @return {string} spelling in Azerbaijani
 */
// eslint-disable-next-line import/prefer-default-export
var spellNumberInAz = function spellNumberInAz(input) {
  if (typeof input !== 'number') {
    throw Error('Üzr istəyirik! The value you passed is neither an integer nor a floating point number.');
  } // it is Number.MAX_SAFE_INTEGER's value :) actually


  if (input > _helpers.MAX_SAFE_VALUE) {
    throw Error("\xDCzr ist\u0259yirik! We do not spell numbers above ".concat(_helpers.MAX_SAFE_VALUE, "."));
  }

  if ((0, _helpers.isInteger)(input)) {
    return (0, _integer["default"])(input);
  }

  return (0, _float["default"])(input);
};

exports.spellNumberInAz = spellNumberInAz;