"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _integer = _interopRequireDefault(require("./integer"));

var _translations = require("../utils/translations");

var _helpers = require("../utils/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * MIT License

Copyright (c) 2018 Orkhan Huseynli

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
 */
var spellFloat = function spellFloat(number) {
  var numberChunks = number.toString().split('.');
  var integerPart = parseInt(numberChunks[0], 10);
  var floatingPartLength = numberChunks[1].length;
  var floatingPart = parseInt(numberChunks[1], 10);
  var numOfFr = '';
  var exponent = 1;

  if (floatingPartLength === 2) {
    exponent = 2;
  } else if (floatingPartLength >= 3 && floatingPartLength < 6) {
    exponent = 3;
    var numOfThousands = parseInt(floatingPart / _helpers.THOUSAND, 10);

    if (numOfThousands > 1 && numOfThousands < 10) {
      numOfThousands = 10;
    } else if (numOfThousands > 10 && numOfThousands < 100) {
      numOfThousands = 100;
    }

    numOfFr = numOfThousands > 1 ? "".concat((0, _integer["default"])(numOfThousands, false), " ") : '';
  } else if (floatingPartLength >= 6 && floatingPartLength < 9) {
    exponent = 6;
    var numOfMillions = parseInt(floatingPart / _helpers.MILLION, 10);

    if (numOfMillions > 1 && numOfMillions < 10) {
      numOfMillions = 10;
    } else if (numOfMillions > 10 && numOfMillions < 100) {
      numOfMillions = 100;
    }

    numOfFr = numOfMillions > 1 ? "".concat((0, _integer["default"])(numOfMillions, false), " ") : '';
  } else if (floatingPartLength >= 9 && floatingPartLength < 12) {
    exponent = 9;
    var numOfBillions = parseInt(floatingPart / _helpers.BILLION, 10);

    if (numOfBillions > 1 && numOfBillions < 10) {
      numOfBillions = 10;
    } else if (numOfBillions > 10 && numOfBillions < 100) {
      numOfBillions = 100;
    }

    numOfFr = numOfBillions > 1 ? "".concat((0, _integer["default"])(numOfBillions, false), " ") : '';
  } else if (floatingPartLength >= 12 && floatingPartLength < 15) {
    exponent = 12;
    var numOfTrillions = parseInt(floatingPart / _helpers.TRILLION, 10);

    if (numOfTrillions > 1 && numOfTrillions < 10) {
      numOfTrillions = 10;
    } else if (numOfTrillions > 10 && numOfTrillions < 100) {
      numOfTrillions = 100;
    }

    numOfFr = numOfTrillions > 1 ? "".concat((0, _integer["default"])(numOfTrillions, false), " ") : '';
  } else if (floatingPartLength >= 15 && floatingPartLength <= 16) {
    exponent = 15;
    var numOfQuadrillions = parseInt(floatingPart / _helpers.QUADRILLION, 10);

    if (numOfQuadrillions > 1 && numOfQuadrillions < 10) {
      numOfQuadrillions = 10;
    } else if (numOfQuadrillions > 10 && numOfQuadrillions < 100) {
      numOfQuadrillions = 100;
    }

    numOfFr = numOfQuadrillions > 1 ? "".concat((0, _integer["default"])(numOfQuadrillions, false), " ") : '';
  }

  var integerPartSpelling = (0, _integer["default"])(integerPart);
  var floatingPartSpelling = (0, _integer["default"])(floatingPart);

  var hundredPoint = _translations.HUNDREDS_AS_WORDS[Math.pow(10, exponent)];

  var prefix = _translations.HUNDREDS_PREFIX[Math.pow(10, exponent)];

  return "".concat(integerPartSpelling, " ").concat(_translations.POINT_AS_WORD, " ").concat(numOfFr).concat(hundredPoint).concat(prefix, " ").concat(floatingPartSpelling);
};

var _default = spellFloat;
exports["default"] = _default;