"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _translations = require("../utils/translations");

var _helpers = require("../utils/helpers");

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

// create cache to store previously
// spelled numbers, so that we don't spell them again
var cache = {};
/**
 * Converts integer into string in Azerbaijani
 * @param {number} input any natural number
 * @param {boolean} spellZeroAtTheEnd whether include zero or not
 * @return {string} spelling of number in Azerbaijani
 */

var spellIntegerMemoized = function spellIntegerMemoized(input) {
  var spellZeroAtTheEnd = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

  // if we have it in the cache
  // then don't bother to calculate it
  if (cache[input]) {
    return cache[input];
  } // define spelling


  var spelling = ''; // we get the sign of number first

  var sign = input < 0 ? "".concat(_translations.NEGATIVE_AS_WORD, " ") : ''; // then we make our number positive to evaluate it

  var number = Math.abs(input); // optional parameter `spellZeroAtTheEnd`
  // so that we can optionally show and hide zero at the end
  // for example we don't want strings like `min sıfır`

  if (input === _helpers.ZERO && spellZeroAtTheEnd) {
    var _DIGITS_AS_WORDS = _slicedToArray(_translations.DIGITS_AS_WORDS, 1),
        zero = _DIGITS_AS_WORDS[0];

    cache[input] = zero;
    return zero;
  }

  if (number > _helpers.ZERO && number < _helpers.TEN) {
    // if number is between 1 (inclusive) and 10
    // then dimply get it from the map
    var spellingOfDigit = _translations.DIGITS_AS_WORDS[number]; // cache the number

    cache[number] = spellingOfDigit; // and add it to our final spelling

    spelling += spellingOfDigit;
  } else if (number >= _helpers.TEN && number < _helpers.HUNDRED) {
    // if number is between 10 (inclusive) and 100
    // then we again need map since there is custom cases
    // between 10 and 100 like `qırx`, `doxsan` etc.
    var numberOfTens = parseInt(number / _helpers.TEN, 10); // find digit after tens point and spell it

    var digitPoint = number % _helpers.TEN > 0 ? _translations.DIGITS_AS_WORDS[number % _helpers.TEN] : '';
    digitPoint = digitPoint ? " ".concat(digitPoint) : digitPoint; // find the spelling of tens value from the map

    var finalSpelling = _translations.TENTHS_AS_WORDS[numberOfTens * _helpers.TEN] + digitPoint; // cache the spelling

    cache[number] = finalSpelling; // add spelling to our final string

    spelling += finalSpelling;
  } else if (number >= _helpers.HUNDRED && number < _helpers.THOUSAND) {
    // if is between 100 and 1000 we don't have custom cases
    // we continue with normal flow after this point
    // fint number of hundreds in the number
    var numberOfHundreds = parseInt(number / _helpers.HUNDRED, 10);
    var remainder = number % _helpers.HUNDRED; // spell number of hundreds in the number if it is more than 1
    // so we don't want to say: `bir yüz doxsan iki`

    var numOfHundredsSpelling = numberOfHundreds > 1 ? spellIntegerMemoized(numberOfHundreds) : ''; // to spell hundred, we get it from our predefined translations
    // so we say the word hundred in azerbaijani

    var hundredsSpelling = numOfHundredsSpelling ? "".concat(numOfHundredsSpelling, " ").concat(_translations.HUNDRED_AS_WORD) : _translations.HUNDRED_AS_WORD; // we get the final spelling

    var _finalSpelling = remainder > 0 ? "".concat(hundredsSpelling, " ").concat(spellIntegerMemoized(remainder, false)) : hundredsSpelling; // add it to the cache


    cache[number] = _finalSpelling; // and do what we're doing before

    spelling += _finalSpelling;
  } else if (number >= _helpers.THOUSAND && number < _helpers.MILLION) {
    // numbers between 1000 and 1 000 000
    // we do the same procedure
    // find number of thousands
    var numberOfThousands = parseInt(number / _helpers.THOUSAND, 10);

    var _remainder = number % _helpers.THOUSAND; // we spell number of thousands
    // just like we did before with hundreds
    // seconds parameter `false` indicates that
    // we don't want to say 0 at the end, like `min sıfır`


    var numOfThousandsSpelling = numberOfThousands > 1 ? spellIntegerMemoized(numberOfThousands, false) : ''; // we say the word thousand in Azerbaijani

    var thousandsSpelling = numOfThousandsSpelling ? "".concat(numOfThousandsSpelling, " ").concat(_translations.THOUSAND_AS_WORD) : _translations.THOUSAND_AS_WORD; // we get our final spelling

    var _finalSpelling2 = _remainder > 0 ? "".concat(thousandsSpelling, " ").concat(spellIntegerMemoized(_remainder, false)) : thousandsSpelling; // cache the result


    cache[number] = _finalSpelling2; // and do the same

    spelling += _finalSpelling2;
  } else if (number >= _helpers.MILLION && number < _helpers.BILLION) {
    // numbers between 1 000 000 and 1 000 000 000
    // we find the number of millions
    var numberOfMillions = parseInt(number / _helpers.MILLION, 10);

    var _remainder2 = number % _helpers.MILLION; // then spell the number of millions
    // this time we need number one, so we want to say: 'bir milyon ...'


    var numOfMillionsSpelling = numberOfMillions > 0 ? spellIntegerMemoized(numberOfMillions, false) : ''; // say the word million in Azerbaijani

    var millionSpelling = numOfMillionsSpelling ? "".concat(numOfMillionsSpelling, " ").concat(_translations.MILLION_AS_WORD) : _translations.MILLION_AS_WORD; // get the final spelling with remainings of million

    var _finalSpelling3 = _remainder2 > 0 ? "".concat(millionSpelling, " ").concat(spellIntegerMemoized(_remainder2, false)) : millionSpelling; // cache the result


    cache[number] = _finalSpelling3; // add it to the spelling

    spelling += _finalSpelling3;
  } else if (number >= _helpers.BILLION && number < _helpers.TRILLION) {
    var numberOfBillions = parseInt(number / _helpers.BILLION, 10);

    var _remainder3 = number % _helpers.BILLION;

    var numOfBillionsSpelling = numberOfBillions > 0 ? spellIntegerMemoized(numberOfBillions, false) : '';
    var billionSpelling = numOfBillionsSpelling ? "".concat(numOfBillionsSpelling, " ").concat(_translations.BILLION_AS_WORD) : _translations.BILLION_AS_WORD; // get the final spelling with remainings of million

    var _finalSpelling4 = _remainder3 > 0 ? "".concat(billionSpelling, " ").concat(spellIntegerMemoized(_remainder3, false)) : billionSpelling;

    spelling += _finalSpelling4;
  } else if (number >= _helpers.TRILLION && number < _helpers.QUADRILLION) {
    var numberOfTrillions = parseInt(number / _helpers.TRILLION, 10);

    var _remainder4 = number % _helpers.TRILLION;

    var numberOfTrillionsSpelling = numberOfTrillions > 0 ? spellIntegerMemoized(numberOfTrillions, false) : '';
    var trillionSpelling = numberOfTrillionsSpelling ? "".concat(numberOfTrillionsSpelling, " ").concat(_translations.TRILLION_AS_WORD) : _translations.TRILLION_AS_WORD; // get the final spelling with remainings of quadrillion

    var _finalSpelling5 = _remainder4 > 0 ? "".concat(trillionSpelling, " ").concat(spellIntegerMemoized(_remainder4, false)) : trillionSpelling;

    spelling += _finalSpelling5;
  } else if (number >= _helpers.QUADRILLION && number <= _helpers.MAX_SAFE_VALUE) {
    var numberOfQuadrillions = parseInt(number / _helpers.QUADRILLION, 10);

    var _remainder5 = number % _helpers.QUADRILLION;

    var numberOfQuadrillionsSpelling = numberOfQuadrillions > 0 ? spellIntegerMemoized(numberOfQuadrillions, false) : '';
    var quadrillionSpelling = numberOfQuadrillionsSpelling ? "".concat(numberOfQuadrillionsSpelling, " ").concat(_translations.QUADRILLION_AS_WORD) : _translations.QUADRILLION_AS_WORD; // get the final spelling with remainings of quadrillion

    var _finalSpelling6 = _remainder5 > 0 ? "".concat(quadrillionSpelling, " ").concat(spellIntegerMemoized(_remainder5, false)) : quadrillionSpelling;

    spelling += _finalSpelling6;
  } // use the sign and eplling finally


  return sign + spelling;
};

var _default = spellIntegerMemoized;
exports["default"] = _default;